package test.metamodel;

import java.util.Properties;
import javax.persistence.EntityManagerFactory;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.data.jpa.repository.config.EnableJpaRepositories;
import org.springframework.orm.jpa.JpaTransactionManager;
import org.springframework.orm.jpa.LocalContainerEntityManagerFactoryBean;
import org.springframework.transaction.PlatformTransactionManager;
import org.springframework.transaction.annotation.EnableTransactionManagement;

/**
 *
 * @author Ralph Moser
 */
@Configuration
@EnableJpaRepositories(basePackages = "test.metamodel.repos")
@EnableTransactionManagement
public class SpringConfig {

    @Bean
    public PlatformTransactionManager transactionManager() {
        JpaTransactionManager txManager = new JpaTransactionManager(entityManagerFactory());
        return txManager;
    }

    @Bean
    public EntityManagerFactory entityManagerFactory() {
        LocalContainerEntityManagerFactoryBean factory = new LocalContainerEntityManagerFactoryBean();
        factory.setPersistenceProviderClass(com.objectdb.jpa.Provider.class);
        factory.setPackagesToScan("test.metamodel.entities");
        Properties jpaProperties = new Properties();
        jpaProperties.put("javax.persistence.jdbc.url", "objectdb://localhost/test.odb");
        jpaProperties.put("javax.persistence.jdbc.user", "admin");
        jpaProperties.put("javax.persistence.jdbc.password", "admin");
        factory.setJpaProperties(jpaProperties);
        factory.afterPropertiesSet();
        return factory.getObject();
    }

}
